"""Mapping of GBD etiologies.

This code is automatically generated by gbd_mapping_generator/risk_builder.py

Any manual changes will be lost.
"""
from .id import reiid, meid, scalar, UNKNOWN
from .base_template import Levels, Tmred, ExposureParameters, Restrictions
from .risk_template import Risk, Risks
from .cause import causes


risk_factors = Risks(
    unsafe_water_source=Risk(
        name='unsafe_water_source',
        kind='risk_factor',
        gbd_id=reiid(83),
        distribution='polytomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='unimproved_and_untreated',
            cat2='unimproved_and_chlorinated',
            cat3='unimproved_and_filtered',
            cat4='improved_and_untreated',
            cat5='improved_and_chlorinated',
            cat6='improved_and_filtered',
            cat7='piped_and_untreated',
            cat8='piped_and_chlorinated',
            cat9='piped_and_filtered',
            cat10='high_quality_piped_and_untreated',
            cat11='high_quality_piped_and_chlorinated',
            cat12='unexposed',
        ),
        affected_causes=(causes.diarrheal_diseases, ),
    ),
    unsafe_sanitation=Risk(
        name='unsafe_sanitation',
        kind='risk_factor',
        gbd_id=reiid(84),
        distribution='polytomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='unimproved_and_untreated',
            cat2='improved',
            cat3='unexposed',
        ),
        affected_causes=(causes.diarrheal_diseases, ),
    ),
    ambient_particulate_matter_pollution=Risk(
        name='ambient_particulate_matter_pollution',
        kind='risk_factor',
        gbd_id=reiid(86),
        distribution=UNKNOWN,
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        affected_causes=(causes.lower_respiratory_infections, causes.tracheal_bronchus_and_lung_cancer, 
                         causes.ischemic_heart_disease, causes.ischemic_stroke, causes.hemorrhagic_stroke, 
                         causes.chronic_obstructive_pulmonary_disease, ),
    ),
    household_air_pollution_from_solid_fuels=Risk(
        name='household_air_pollution_from_solid_fuels',
        kind='risk_factor',
        gbd_id=reiid(87),
        distribution='dichotomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='exposed',
            cat2='unexposed',
        ),
        affected_causes=(causes.lower_respiratory_infections, causes.tracheal_bronchus_and_lung_cancer, 
                         causes.ischemic_heart_disease, causes.ischemic_stroke, causes.hemorrhagic_stroke, 
                         causes.chronic_obstructive_pulmonary_disease, causes.cataract, ),
    ),
    ambient_ozone_pollution=Risk(
        name='ambient_ozone_pollution',
        kind='risk_factor',
        gbd_id=reiid(88),
        distribution='unknown_continuous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=True,
            yld_only=False,
        ),
        tmred=Tmred(
            distribution='uniform',
            min=scalar(30.0),
            max=scalar(50.0),
            inverted=False,
        ),
        exposure_parameters=ExposureParameters(
            scale=scalar(10.0),
            max_rr=scalar(100.0),
        ),
        affected_causes=(causes.chronic_obstructive_pulmonary_disease, ),
    ),
    residential_radon=Risk(
        name='residential_radon',
        kind='risk_factor',
        gbd_id=reiid(90),
        distribution='lognormal',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        tmred=Tmred(
            distribution='uniform',
            min=scalar(7.0),
            max=scalar(14.8),
            inverted=False,
        ),
        exposure_parameters=ExposureParameters(
            scale=scalar(1.0),
            max_rr=scalar(10000.0),
        ),
        affected_causes=(causes.tracheal_bronchus_and_lung_cancer, ),
    ),
    child_underweight=Risk(
        name='child_underweight',
        kind='risk_factor',
        gbd_id=reiid(94),
        distribution='polytomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='<-3_sd',
            cat2='-3_to_-2_sd',
            cat3='-2_to_-1_sd',
            cat4='unexposed',
        ),
        affected_causes=(causes.diarrheal_diseases, causes.lower_respiratory_infections, causes.measles, 
                         causes.protein_energy_malnutrition, ),
    ),
    iron_deficiency=Risk(
        name='iron_deficiency',
        kind='risk_factor',
        gbd_id=reiid(95),
        distribution='normal',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        tmred=Tmred(
            distribution=UNKNOWN,
            min=UNKNOWN,
            max=UNKNOWN,
            inverted=True,
        ),
        exposure_parameters=ExposureParameters(
            scale=scalar(10.0),
            max_rr=scalar(5000.0),
        ),
        affected_causes=(causes.maternal_hemorrhage, causes.maternal_sepsis_and_other_maternal_infections, 
                         causes.iron_deficiency_anemia, ),
    ),
    vitamin_a_deficiency=Risk(
        name='vitamin_a_deficiency',
        kind='risk_factor',
        gbd_id=reiid(96),
        distribution='dichotomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='exposed',
            cat2='unexposed',
        ),
        affected_causes=(causes.diarrheal_diseases, causes.measles, causes.vitamin_a_deficiency, ),
    ),
    zinc_deficiency=Risk(
        name='zinc_deficiency',
        kind='risk_factor',
        gbd_id=reiid(97),
        distribution='dichotomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='exposed',
            cat2='unexposed',
        ),
        affected_causes=(causes.diarrheal_diseases, causes.lower_respiratory_infections, ),
    ),
    secondhand_smoke=Risk(
        name='secondhand_smoke',
        kind='risk_factor',
        gbd_id=reiid(100),
        distribution='dichotomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='exposed',
            cat2='unexposed',
        ),
        affected_causes=(causes.lower_respiratory_infections, causes.otitis_media, 
                         causes.tracheal_bronchus_and_lung_cancer, causes.breast_cancer, 
                         causes.ischemic_heart_disease, causes.ischemic_stroke, causes.hemorrhagic_stroke, 
                         causes.chronic_obstructive_pulmonary_disease, causes.diabetes_mellitus, ),
    ),
    alcohol_use=Risk(
        name='alcohol_use',
        kind='risk_factor',
        gbd_id=reiid(102),
        distribution=UNKNOWN,
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        affected_causes=(causes.lower_respiratory_infections, causes.esophageal_cancer, 
                         causes.liver_cancer_due_to_alcohol_use, causes.larynx_cancer, causes.breast_cancer, 
                         causes.colon_and_rectum_cancer, causes.lip_and_oral_cavity_cancer, 
                         causes.nasopharynx_cancer, causes.other_pharynx_cancer, causes.ischemic_heart_disease, 
                         causes.ischemic_stroke, causes.hemorrhagic_stroke, causes.hypertensive_heart_disease, 
                         causes.atrial_fibrillation_and_flutter, 
                         causes.cirrhosis_and_other_chronic_liver_diseases_due_to_alcohol_use, causes.pancreatitis, 
                         causes.epilepsy, causes.alcohol_use_disorders, causes.diabetes_mellitus, 
                         causes.pedestrian_road_injuries, causes.cyclist_road_injuries, 
                         causes.motorcyclist_road_injuries, causes.motor_vehicle_road_injuries, 
                         causes.other_road_injuries, causes.other_transport_injuries, causes.drowning, 
                         causes.fire_heat_and_hot_substances, causes.poisonings, 
                         causes.unintentional_firearm_injuries, causes.other_unintentional_injuries, 
                         causes.self_harm_by_firearm, causes.self_harm_by_other_specified_means, 
                         causes.physical_violence_by_firearm, causes.physical_violence_by_sharp_object, 
                         causes.physical_violence_by_other_means, causes.drug_susceptible_tuberculosis, 
                         causes.alcoholic_cardiomyopathy, 
                         causes.multidrug_resistant_tuberculosis_without_extensive_drug_resistance, 
                         causes.extensively_drug_resistant_tuberculosis, ),
    ),
    high_total_cholesterol=Risk(
        name='high_total_cholesterol',
        kind='risk_factor',
        gbd_id=reiid(106),
        distribution='ensemble',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        tmred=Tmred(
            distribution='uniform',
            min=scalar(2.78),
            max=scalar(3.38),
            inverted=False,
        ),
        exposure_parameters=ExposureParameters(
            scale=scalar(1.0),
            max_rr=scalar(10.0),
        ),
        affected_causes=(causes.ischemic_heart_disease, causes.ischemic_stroke, ),
    ),
    high_systolic_blood_pressure=Risk(
        name='high_systolic_blood_pressure',
        kind='risk_factor',
        gbd_id=reiid(107),
        distribution='ensemble',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        tmred=Tmred(
            distribution='uniform',
            min=scalar(110.0),
            max=scalar(115.0),
            inverted=False,
        ),
        exposure_parameters=ExposureParameters(
            scale=scalar(10.0),
            max_rr=scalar(200.0),
        ),
        affected_causes=(causes.rheumatic_heart_disease, causes.ischemic_heart_disease, causes.ischemic_stroke, 
                         causes.hemorrhagic_stroke, causes.hypertensive_heart_disease, 
                         causes.atrial_fibrillation_and_flutter, causes.aortic_aneurysm, 
                         causes.peripheral_artery_disease, causes.endocarditis, 
                         causes.other_cardiovascular_and_circulatory_diseases, 
                         causes.chronic_kidney_disease_due_to_diabetes_mellitus, 
                         causes.chronic_kidney_disease_due_to_hypertension, 
                         causes.chronic_kidney_disease_due_to_glomerulonephritis, 
                         causes.chronic_kidney_disease_due_to_other_causes, causes.other_cardiomyopathy, ),
    ),
    high_body_mass_index=Risk(
        name='high_body_mass_index',
        kind='risk_factor',
        gbd_id=reiid(108),
        distribution='ensemble',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        tmred=Tmred(
            distribution='uniform',
            min=scalar(20.0),
            max=scalar(25.0),
            inverted=False,
        ),
        exposure_parameters=ExposureParameters(
            scale=scalar(5.0),
            max_rr=scalar(50.0),
        ),
        affected_causes=(causes.esophageal_cancer, causes.liver_cancer_due_to_hepatitis_b, 
                         causes.liver_cancer_due_to_hepatitis_c, causes.liver_cancer_due_to_alcohol_use, 
                         causes.liver_cancer_due_to_other_causes, causes.breast_cancer, causes.uterine_cancer, 
                         causes.colon_and_rectum_cancer, causes.gallbladder_and_biliary_tract_cancer, 
                         causes.pancreatic_cancer, causes.ovarian_cancer, causes.kidney_cancer, 
                         causes.thyroid_cancer, causes.non_hodgkin_lymphoma, causes.multiple_myeloma, 
                         causes.ischemic_heart_disease, causes.ischemic_stroke, causes.hemorrhagic_stroke, 
                         causes.hypertensive_heart_disease, causes.atrial_fibrillation_and_flutter, causes.asthma, 
                         causes.gallbladder_and_biliary_diseases, causes.alzheimer_disease_and_other_dementias, 
                         causes.diabetes_mellitus, causes.chronic_kidney_disease_due_to_diabetes_mellitus, 
                         causes.chronic_kidney_disease_due_to_hypertension, 
                         causes.chronic_kidney_disease_due_to_glomerulonephritis, 
                         causes.chronic_kidney_disease_due_to_other_causes, causes.osteoarthritis, 
                         causes.low_back_pain, causes.gout, causes.cataract, causes.acute_lymphoid_leukemia, 
                         causes.chronic_lymphoid_leukemia, causes.acute_myeloid_leukemia, 
                         causes.chronic_myeloid_leukemia, causes.other_leukemia, ),
    ),
    low_bone_mineral_density=Risk(
        name='low_bone_mineral_density',
        kind='risk_factor',
        gbd_id=reiid(109),
        distribution='ensemble',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        tmred=Tmred(
            distribution='uniform',
            min=scalar(1.0),
            max=scalar(1.3),
            inverted=True,
        ),
        exposure_parameters=ExposureParameters(
            scale=scalar(0.1),
            max_rr=scalar(5.0),
        ),
        affected_causes=(causes.pedestrian_road_injuries, causes.cyclist_road_injuries, 
                         causes.motorcyclist_road_injuries, causes.motor_vehicle_road_injuries, 
                         causes.other_road_injuries, causes.other_transport_injuries, causes.falls, 
                         causes.other_exposure_to_mechanical_forces, causes.non_venomous_animal_contact, 
                         causes.physical_violence_by_other_means, causes.exposure_to_forces_of_nature, ),
    ),
    diet_low_in_fruits=Risk(
        name='diet_low_in_fruits',
        kind='risk_factor',
        gbd_id=reiid(111),
        distribution='ensemble',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        tmred=Tmred(
            distribution='uniform',
            min=scalar(200.0),
            max=scalar(300.0),
            inverted=True,
        ),
        exposure_parameters=ExposureParameters(
            scale=scalar(100.0),
            max_rr=scalar(400.0),
        ),
        affected_causes=(causes.esophageal_cancer, causes.larynx_cancer, causes.tracheal_bronchus_and_lung_cancer, 
                         causes.lip_and_oral_cavity_cancer, causes.nasopharynx_cancer, causes.other_pharynx_cancer, 
                         causes.ischemic_heart_disease, causes.ischemic_stroke, causes.hemorrhagic_stroke, 
                         causes.diabetes_mellitus, ),
    ),
    diet_low_in_vegetables=Risk(
        name='diet_low_in_vegetables',
        kind='risk_factor',
        gbd_id=reiid(112),
        distribution='ensemble',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        tmred=Tmred(
            distribution='uniform',
            min=scalar(290.0),
            max=scalar(430.0),
            inverted=True,
        ),
        exposure_parameters=ExposureParameters(
            scale=scalar(100.0),
            max_rr=scalar(450.0),
        ),
        affected_causes=(causes.ischemic_heart_disease, causes.ischemic_stroke, causes.hemorrhagic_stroke, ),
    ),
    diet_low_in_whole_grains=Risk(
        name='diet_low_in_whole_grains',
        kind='risk_factor',
        gbd_id=reiid(113),
        distribution='ensemble',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        tmred=Tmred(
            distribution='uniform',
            min=scalar(100.0),
            max=scalar(150.0),
            inverted=True,
        ),
        exposure_parameters=ExposureParameters(
            scale=scalar(50.0),
            max_rr=scalar(150.0),
        ),
        affected_causes=(causes.ischemic_heart_disease, causes.ischemic_stroke, causes.hemorrhagic_stroke, 
                         causes.diabetes_mellitus, ),
    ),
    diet_low_in_nuts_and_seeds=Risk(
        name='diet_low_in_nuts_and_seeds',
        kind='risk_factor',
        gbd_id=reiid(114),
        distribution='ensemble',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        tmred=Tmred(
            distribution='uniform',
            min=scalar(16.0),
            max=scalar(25.0),
            inverted=True,
        ),
        exposure_parameters=ExposureParameters(
            scale=scalar(4.05),
            max_rr=scalar(24.0),
        ),
        affected_causes=(causes.ischemic_heart_disease, causes.diabetes_mellitus, ),
    ),
    diet_low_in_milk=Risk(
        name='diet_low_in_milk',
        kind='risk_factor',
        gbd_id=reiid(115),
        distribution='ensemble',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        tmred=Tmred(
            distribution='uniform',
            min=scalar(350.0),
            max=scalar(520.0),
            inverted=True,
        ),
        exposure_parameters=ExposureParameters(
            scale=scalar(226.8),
            max_rr=scalar(680.0),
        ),
        affected_causes=(causes.colon_and_rectum_cancer, ),
    ),
    diet_high_in_red_meat=Risk(
        name='diet_high_in_red_meat',
        kind='risk_factor',
        gbd_id=reiid(116),
        distribution='ensemble',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        tmred=Tmred(
            distribution='uniform',
            min=scalar(18.0),
            max=scalar(27.0),
            inverted=False,
        ),
        exposure_parameters=ExposureParameters(
            scale=scalar(100.0),
            max_rr=scalar(1000.0),
        ),
        affected_causes=(causes.colon_and_rectum_cancer, causes.diabetes_mellitus, ),
    ),
    diet_high_in_processed_meat=Risk(
        name='diet_high_in_processed_meat',
        kind='risk_factor',
        gbd_id=reiid(117),
        distribution='ensemble',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        tmred=Tmred(
            distribution='uniform',
            min=scalar(0.0),
            max=scalar(4.0),
            inverted=False,
        ),
        exposure_parameters=ExposureParameters(
            scale=scalar(50.0),
            max_rr=scalar(1000.0),
        ),
        affected_causes=(causes.colon_and_rectum_cancer, causes.ischemic_heart_disease, causes.diabetes_mellitus, ),
    ),
    diet_high_in_sugar_sweetened_beverages=Risk(
        name='diet_high_in_sugar_sweetened_beverages',
        kind='risk_factor',
        gbd_id=reiid(118),
        distribution='ensemble',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        tmred=Tmred(
            distribution='uniform',
            min=scalar(0.0),
            max=scalar(5.0),
            inverted=False,
        ),
        exposure_parameters=ExposureParameters(
            scale=scalar(226.8),
            max_rr=scalar(5000.0),
        ),
        affected_causes=(causes.esophageal_cancer, causes.liver_cancer_due_to_hepatitis_b, 
                         causes.liver_cancer_due_to_hepatitis_c, causes.liver_cancer_due_to_alcohol_use, 
                         causes.liver_cancer_due_to_other_causes, causes.breast_cancer, causes.uterine_cancer, 
                         causes.colon_and_rectum_cancer, causes.gallbladder_and_biliary_tract_cancer, 
                         causes.pancreatic_cancer, causes.ovarian_cancer, causes.kidney_cancer, 
                         causes.thyroid_cancer, causes.non_hodgkin_lymphoma, causes.multiple_myeloma, 
                         causes.ischemic_heart_disease, causes.ischemic_stroke, causes.hemorrhagic_stroke, 
                         causes.hypertensive_heart_disease, causes.atrial_fibrillation_and_flutter, causes.asthma, 
                         causes.gallbladder_and_biliary_diseases, causes.alzheimer_disease_and_other_dementias, 
                         causes.diabetes_mellitus, causes.chronic_kidney_disease_due_to_diabetes_mellitus, 
                         causes.chronic_kidney_disease_due_to_hypertension, 
                         causes.chronic_kidney_disease_due_to_glomerulonephritis, 
                         causes.chronic_kidney_disease_due_to_other_causes, causes.osteoarthritis, 
                         causes.low_back_pain, causes.gout, causes.cataract, causes.acute_lymphoid_leukemia, 
                         causes.chronic_lymphoid_leukemia, causes.acute_myeloid_leukemia, 
                         causes.chronic_myeloid_leukemia, causes.other_leukemia, ),
    ),
    diet_low_in_fiber=Risk(
        name='diet_low_in_fiber',
        kind='risk_factor',
        gbd_id=reiid(119),
        distribution='ensemble',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        tmred=Tmred(
            distribution='uniform',
            min=scalar(19.0),
            max=scalar(28.0),
            inverted=True,
        ),
        exposure_parameters=ExposureParameters(
            scale=scalar(20.0),
            max_rr=scalar(32.0),
        ),
        affected_causes=(causes.colon_and_rectum_cancer, causes.ischemic_heart_disease, ),
    ),
    diet_low_in_seafood_omega_3_fatty_acids=Risk(
        name='diet_low_in_seafood_omega_3_fatty_acids',
        kind='risk_factor',
        gbd_id=reiid(121),
        distribution='ensemble',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=True,
            yld_only=False,
        ),
        tmred=Tmred(
            distribution='uniform',
            min=scalar(200.0),
            max=scalar(300.0),
            inverted=True,
        ),
        exposure_parameters=ExposureParameters(
            scale=scalar(100.0),
            max_rr=scalar(1000.0),
        ),
        affected_causes=(causes.ischemic_heart_disease, ),
    ),
    diet_low_in_polyunsaturated_fatty_acids=Risk(
        name='diet_low_in_polyunsaturated_fatty_acids',
        kind='risk_factor',
        gbd_id=reiid(122),
        distribution='ensemble',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        tmred=Tmred(
            distribution='uniform',
            min=scalar(0.09),
            max=scalar(0.13),
            inverted=True,
        ),
        exposure_parameters=ExposureParameters(
            scale=scalar(0.05),
            max_rr=scalar(0.149),
        ),
        affected_causes=(causes.ischemic_heart_disease, ),
    ),
    diet_high_in_trans_fatty_acids=Risk(
        name='diet_high_in_trans_fatty_acids',
        kind='risk_factor',
        gbd_id=reiid(123),
        distribution='ensemble',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        tmred=Tmred(
            distribution='uniform',
            min=scalar(0.0),
            max=scalar(0.01),
            inverted=False,
        ),
        exposure_parameters=ExposureParameters(
            scale=scalar(0.02),
            max_rr=scalar(1.0),
        ),
        affected_causes=(causes.ischemic_heart_disease, ),
    ),
    diet_high_in_sodium=Risk(
        name='diet_high_in_sodium',
        kind='risk_factor',
        gbd_id=reiid(124),
        distribution='ensemble',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        tmred=Tmred(
            distribution='uniform',
            min=scalar(1.0),
            max=scalar(5.0),
            inverted=False,
        ),
        exposure_parameters=ExposureParameters(
            scale=scalar(1.0),
            max_rr=scalar(50.0),
        ),
        affected_causes=(causes.stomach_cancer, causes.rheumatic_heart_disease, causes.ischemic_heart_disease, 
                         causes.ischemic_stroke, causes.hemorrhagic_stroke, causes.hypertensive_heart_disease, 
                         causes.atrial_fibrillation_and_flutter, causes.aortic_aneurysm, 
                         causes.peripheral_artery_disease, causes.endocarditis, 
                         causes.other_cardiovascular_and_circulatory_diseases, 
                         causes.chronic_kidney_disease_due_to_diabetes_mellitus, 
                         causes.chronic_kidney_disease_due_to_hypertension, 
                         causes.chronic_kidney_disease_due_to_glomerulonephritis, 
                         causes.chronic_kidney_disease_due_to_other_causes, causes.other_cardiomyopathy, ),
    ),
    low_physical_activity=Risk(
        name='low_physical_activity',
        kind='risk_factor',
        gbd_id=reiid(125),
        distribution='ensemble',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        tmred=Tmred(
            distribution='uniform',
            min=scalar(3000.0),
            max=scalar(4500.0),
            inverted=True,
        ),
        exposure_parameters=ExposureParameters(
            scale=scalar(600.0),
            max_rr=scalar(5000.0),
        ),
        affected_causes=(causes.breast_cancer, causes.colon_and_rectum_cancer, causes.ischemic_heart_disease, 
                         causes.ischemic_stroke, causes.diabetes_mellitus, ),
    ),
    occupational_asthmagens=Risk(
        name='occupational_asthmagens',
        kind='risk_factor',
        gbd_id=reiid(128),
        distribution='polytomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='admin',
            cat2='technical',
            cat3='sales',
            cat4='agriculture',
            cat5='mining',
            cat6='transport',
            cat7='manufact',
            cat8='services',
            cat9='unexposed',
        ),
        affected_causes=(causes.asthma, ),
    ),
    occupational_particulate_matter_gases_and_fumes=Risk(
        name='occupational_particulate_matter_gases_and_fumes',
        kind='risk_factor',
        gbd_id=reiid(129),
        distribution='polytomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='gases_and_fumes_exposure_high',
            cat2='gases_and_fumes_exposure_low',
            cat3='unexposed',
        ),
        affected_causes=(causes.chronic_obstructive_pulmonary_disease, causes.coal_workers_pneumoconiosis, 
                         causes.other_pneumoconiosis, ),
    ),
    occupational_noise=Risk(
        name='occupational_noise',
        kind='risk_factor',
        gbd_id=reiid(130),
        distribution='polytomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=True,
        ),
        levels=Levels(
            cat1='high_exposure_(>90db)',
            cat2='low_exposure_(85-90db)',
            cat3='unexposed',
        ),
        affected_causes=(causes.age_related_and_other_hearing_loss, ),
    ),
    occupational_injuries=Risk(
        name='occupational_injuries',
        kind='risk_factor',
        gbd_id=reiid(131),
        distribution=UNKNOWN,
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=True,
            yld_only=False,
        ),
        affected_causes=(causes.pedestrian_road_injuries, causes.cyclist_road_injuries, 
                         causes.motorcyclist_road_injuries, causes.motor_vehicle_road_injuries, 
                         causes.other_road_injuries, causes.other_transport_injuries, causes.falls, causes.drowning, 
                         causes.fire_heat_and_hot_substances, causes.poisonings, 
                         causes.unintentional_firearm_injuries, causes.unintentional_suffocation, 
                         causes.other_exposure_to_mechanical_forces, causes.venomous_animal_contact, 
                         causes.non_venomous_animal_contact, causes.pulmonary_aspiration_and_foreign_body_in_airway, 
                         causes.foreign_body_in_other_body_part, causes.other_unintentional_injuries, ),
    ),
    occupational_ergonomic_factors=Risk(
        name='occupational_ergonomic_factors',
        kind='risk_factor',
        gbd_id=reiid(132),
        distribution='polytomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='professional_technical_and_related_workers',
            cat2='administrative_and_managerial_workers',
            cat3='clerical_and_related_workers',
            cat4='sales_workers',
            cat5='service_workers',
            cat6='agriculture_animal_husbandry_and_forestry_workers_fishermen_and_hunters',
            cat7='production_and_related_workers_transport_equipment_operators_and_labourers',
            cat8='unexposed',
        ),
        affected_causes=(causes.low_back_pain, ),
    ),
    non_exclusive_breastfeeding=Risk(
        name='non_exclusive_breastfeeding',
        kind='risk_factor',
        gbd_id=reiid(136),
        distribution='polytomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='none',
            cat2='partial',
            cat3='predominant',
            cat4='unexposed',
        ),
        affected_causes=(causes.diarrheal_diseases, causes.lower_respiratory_infections, ),
    ),
    discontinued_breastfeeding=Risk(
        name='discontinued_breastfeeding',
        kind='risk_factor',
        gbd_id=reiid(137),
        distribution='dichotomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='exposed',
            cat2='unexposed',
        ),
        affected_causes=(causes.diarrheal_diseases, ),
    ),
    drug_use_dependence_and_blood_borne_viruses=Risk(
        name='drug_use_dependence_and_blood_borne_viruses',
        kind='risk_factor',
        gbd_id=reiid(138),
        distribution=UNKNOWN,
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        affected_causes=(causes.hiv_aids_resulting_in_other_diseases, causes.hepatitis_b, causes.hepatitis_c, 
                         causes.liver_cancer_due_to_hepatitis_b, causes.liver_cancer_due_to_hepatitis_c, 
                         causes.cirrhosis_and_other_chronic_liver_diseases_due_to_hepatitis_b, 
                         causes.cirrhosis_and_other_chronic_liver_diseases_due_to_hepatitis_c, 
                         causes.opioid_use_disorders, causes.cocaine_use_disorders, causes.amphetamine_use_disorders, 
                         causes.cannabis_use_disorders, causes.other_drug_use_disorders, 
                         causes.drug_susceptible_hiv_aids_tuberculosis, 
                         causes.multidrug_resistant_hiv_aids_tuberculosis_without_extensive_drug_resistance, 
                         causes.extensively_drug_resistant_hiv_aids_tuberculosis, ),
    ),
    suicide_due_to_drug_use_disorders=Risk(
        name='suicide_due_to_drug_use_disorders',
        kind='risk_factor',
        gbd_id=reiid(140),
        distribution=UNKNOWN,
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        affected_causes=(causes.self_harm_by_firearm, causes.self_harm_by_other_specified_means, ),
    ),
    high_fasting_plasma_glucose_continuous=Risk(
        name='high_fasting_plasma_glucose_continuous',
        kind='risk_factor',
        gbd_id=reiid(141),
        distribution='ensemble',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        tmred=Tmred(
            distribution='uniform',
            min=scalar(4.88488),
            max=scalar(5.301205),
            inverted=False,
        ),
        exposure_parameters=ExposureParameters(
            scale=scalar(1.0),
            max_rr=scalar(30.0),
        ),
        affected_causes=(causes.ischemic_heart_disease, causes.ischemic_stroke, causes.hemorrhagic_stroke, 
                         causes.diabetes_mellitus, causes.chronic_kidney_disease_due_to_diabetes_mellitus, 
                         causes.chronic_kidney_disease_due_to_hypertension, 
                         causes.chronic_kidney_disease_due_to_glomerulonephritis, 
                         causes.chronic_kidney_disease_due_to_other_causes, ),
    ),
    high_fasting_plasma_glucose_categorical=Risk(
        name='high_fasting_plasma_glucose_categorical',
        kind='risk_factor',
        gbd_id=reiid(142),
        distribution='dichotomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='exposed',
            cat2='unexposed',
        ),
        affected_causes=(causes.liver_cancer_due_to_other_causes, causes.tracheal_bronchus_and_lung_cancer, 
                         causes.breast_cancer, causes.colon_and_rectum_cancer, causes.pancreatic_cancer, 
                         causes.ovarian_cancer, causes.bladder_cancer, causes.peripheral_artery_disease, 
                         causes.alzheimer_disease_and_other_dementias, causes.glaucoma, causes.cataract, 
                         causes.drug_susceptible_tuberculosis, 
                         causes.multidrug_resistant_tuberculosis_without_extensive_drug_resistance, 
                         causes.extensively_drug_resistant_tuberculosis, ),
    ),
    diet_low_in_calcium=Risk(
        name='diet_low_in_calcium',
        kind='risk_factor',
        gbd_id=reiid(147),
        distribution='ensemble',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        tmred=Tmred(
            distribution='uniform',
            min=scalar(1.0),
            max=scalar(1.5),
            inverted=True,
        ),
        exposure_parameters=ExposureParameters(
            scale=scalar(1.0),
            max_rr=scalar(50.0),
        ),
        affected_causes=(causes.colon_and_rectum_cancer, ),
    ),
    occupational_exposure_to_asbestos=Risk(
        name='occupational_exposure_to_asbestos',
        kind='risk_factor',
        gbd_id=reiid(150),
        distribution='dichotomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='exposed',
            cat2='unexposed',
        ),
        affected_causes=(causes.larynx_cancer, causes.tracheal_bronchus_and_lung_cancer, causes.ovarian_cancer, 
                         causes.mesothelioma, causes.asbestosis, ),
    ),
    occupational_exposure_to_arsenic=Risk(
        name='occupational_exposure_to_arsenic',
        kind='risk_factor',
        gbd_id=reiid(151),
        distribution='polytomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='high_exposure',
            cat2='low_exposure',
            cat3='unexposed',
        ),
        affected_causes=(causes.tracheal_bronchus_and_lung_cancer, ),
    ),
    occupational_exposure_to_benzene=Risk(
        name='occupational_exposure_to_benzene',
        kind='risk_factor',
        gbd_id=reiid(152),
        distribution='polytomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='high_exposure',
            cat2='low_exposure',
            cat3='unexposed',
        ),
        affected_causes=(causes.acute_lymphoid_leukemia, causes.chronic_lymphoid_leukemia, 
                         causes.acute_myeloid_leukemia, causes.chronic_myeloid_leukemia, causes.other_leukemia, ),
    ),
    occupational_exposure_to_beryllium=Risk(
        name='occupational_exposure_to_beryllium',
        kind='risk_factor',
        gbd_id=reiid(153),
        distribution='polytomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='high_exposure',
            cat2='low_exposure',
            cat3='unexposed',
        ),
        affected_causes=(causes.tracheal_bronchus_and_lung_cancer, ),
    ),
    occupational_exposure_to_cadmium=Risk(
        name='occupational_exposure_to_cadmium',
        kind='risk_factor',
        gbd_id=reiid(154),
        distribution='polytomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='high_exposure',
            cat2='low_exposure',
            cat3='unexposed',
        ),
        affected_causes=(causes.tracheal_bronchus_and_lung_cancer, ),
    ),
    occupational_exposure_to_chromium=Risk(
        name='occupational_exposure_to_chromium',
        kind='risk_factor',
        gbd_id=reiid(155),
        distribution='polytomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='high_exposure',
            cat2='low_exposure',
            cat3='unexposed',
        ),
        affected_causes=(causes.tracheal_bronchus_and_lung_cancer, ),
    ),
    occupational_exposure_to_diesel_engine_exhaust=Risk(
        name='occupational_exposure_to_diesel_engine_exhaust',
        kind='risk_factor',
        gbd_id=reiid(156),
        distribution='polytomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='high_exposure',
            cat2='low_exposure',
            cat3='unexposed',
        ),
        affected_causes=(causes.tracheal_bronchus_and_lung_cancer, ),
    ),
    occupational_exposure_to_secondhand_smoke=Risk(
        name='occupational_exposure_to_secondhand_smoke',
        kind='risk_factor',
        gbd_id=reiid(157),
        distribution='polytomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='high_exposure',
            cat2='low_exposure',
            cat3='unexposed',
        ),
        affected_causes=(causes.lower_respiratory_infections, causes.otitis_media, 
                         causes.tracheal_bronchus_and_lung_cancer, causes.breast_cancer, 
                         causes.ischemic_heart_disease, causes.ischemic_stroke, causes.hemorrhagic_stroke, 
                         causes.chronic_obstructive_pulmonary_disease, causes.diabetes_mellitus, ),
    ),
    occupational_exposure_to_formaldehyde=Risk(
        name='occupational_exposure_to_formaldehyde',
        kind='risk_factor',
        gbd_id=reiid(158),
        distribution='polytomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='high_exposure',
            cat2='low_exposure',
            cat3='unexposed',
        ),
        affected_causes=(causes.nasopharynx_cancer, causes.acute_lymphoid_leukemia, causes.chronic_lymphoid_leukemia, 
                         causes.acute_myeloid_leukemia, causes.chronic_myeloid_leukemia, causes.other_leukemia, ),
    ),
    occupational_exposure_to_nickel=Risk(
        name='occupational_exposure_to_nickel',
        kind='risk_factor',
        gbd_id=reiid(159),
        distribution='polytomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='high_exposure',
            cat2='low_exposure',
            cat3='unexposed',
        ),
        affected_causes=(causes.tracheal_bronchus_and_lung_cancer, ),
    ),
    occupational_exposure_to_polycyclic_aromatic_hydrocarbons=Risk(
        name='occupational_exposure_to_polycyclic_aromatic_hydrocarbons',
        kind='risk_factor',
        gbd_id=reiid(160),
        distribution='polytomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='high_exposure',
            cat2='low_exposure',
            cat3='unexposed',
        ),
        affected_causes=(causes.tracheal_bronchus_and_lung_cancer, ),
    ),
    occupational_exposure_to_silica=Risk(
        name='occupational_exposure_to_silica',
        kind='risk_factor',
        gbd_id=reiid(161),
        distribution='polytomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='high_exposure',
            cat2='low_exposure',
            cat3='unexposed',
        ),
        affected_causes=(causes.tracheal_bronchus_and_lung_cancer, causes.silicosis, ),
    ),
    occupational_exposure_to_sulfuric_acid=Risk(
        name='occupational_exposure_to_sulfuric_acid',
        kind='risk_factor',
        gbd_id=reiid(162),
        distribution='polytomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='high_exposure',
            cat2='low_exposure',
            cat3='unexposed',
        ),
        affected_causes=(causes.larynx_cancer, ),
    ),
    smoking_sir_approach=Risk(
        name='smoking_sir_approach',
        kind='risk_factor',
        gbd_id=reiid(165),
        distribution='dichotomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='exposed',
            cat2='unexposed',
        ),
        affected_causes=(causes.esophageal_cancer, causes.stomach_cancer, causes.liver_cancer_due_to_hepatitis_b, 
                         causes.liver_cancer_due_to_hepatitis_c, causes.liver_cancer_due_to_alcohol_use, 
                         causes.liver_cancer_due_to_other_causes, causes.larynx_cancer, 
                         causes.tracheal_bronchus_and_lung_cancer, causes.breast_cancer, causes.cervical_cancer, 
                         causes.prostate_cancer, causes.colon_and_rectum_cancer, causes.lip_and_oral_cavity_cancer, 
                         causes.nasopharynx_cancer, causes.pancreatic_cancer, causes.kidney_cancer, 
                         causes.bladder_cancer, causes.chronic_obstructive_pulmonary_disease, 
                         causes.other_chronic_respiratory_diseases, causes.acute_lymphoid_leukemia, 
                         causes.chronic_lymphoid_leukemia, causes.acute_myeloid_leukemia, 
                         causes.chronic_myeloid_leukemia, causes.other_leukemia, ),
    ),
    smoking_prevalence_approach=Risk(
        name='smoking_prevalence_approach',
        kind='risk_factor',
        gbd_id=reiid(166),
        distribution='dichotomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='exposed',
            cat2='unexposed',
        ),
        affected_causes=(causes.lower_respiratory_infections, causes.ischemic_heart_disease, causes.ischemic_stroke, 
                         causes.hemorrhagic_stroke, causes.hypertensive_heart_disease, 
                         causes.atrial_fibrillation_and_flutter, causes.aortic_aneurysm, 
                         causes.peripheral_artery_disease, causes.other_cardiovascular_and_circulatory_diseases, 
                         causes.asthma, causes.peptic_ulcer_disease, causes.gallbladder_and_biliary_diseases, 
                         causes.alzheimer_disease_and_other_dementias, causes.parkinson_disease, 
                         causes.multiple_sclerosis, causes.diabetes_mellitus, causes.rheumatoid_arthritis, 
                         causes.low_back_pain, causes.cataract, causes.macular_degeneration, 
                         causes.pedestrian_road_injuries, causes.cyclist_road_injuries, 
                         causes.motorcyclist_road_injuries, causes.motor_vehicle_road_injuries, 
                         causes.other_road_injuries, causes.other_transport_injuries, causes.falls, 
                         causes.other_exposure_to_mechanical_forces, causes.non_venomous_animal_contact, 
                         causes.physical_violence_by_other_means, causes.exposure_to_forces_of_nature, 
                         causes.drug_susceptible_tuberculosis, 
                         causes.multidrug_resistant_tuberculosis_without_extensive_drug_resistance, 
                         causes.extensively_drug_resistant_tuberculosis, ),
    ),
    intimate_partner_violence_exposure_approach=Risk(
        name='intimate_partner_violence_exposure_approach',
        kind='risk_factor',
        gbd_id=reiid(167),
        distribution='dichotomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=True,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='exposed',
            cat2='unexposed',
        ),
        affected_causes=(causes.maternal_abortion_miscarriage_and_ectopic_pregnancy, 
                         causes.major_depressive_disorder, ),
    ),
    intimate_partner_violence_direct_paf_approach=Risk(
        name='intimate_partner_violence_direct_paf_approach',
        kind='risk_factor',
        gbd_id=reiid(168),
        distribution=UNKNOWN,
        restrictions=Restrictions(
            male_only=False,
            female_only=True,
            yll_only=False,
            yld_only=False,
        ),
        affected_causes=(causes.physical_violence_by_firearm, causes.physical_violence_by_sharp_object, 
                         causes.physical_violence_by_other_means, causes.sexual_violence, ),
    ),
    unsafe_sex=Risk(
        name='unsafe_sex',
        kind='risk_factor',
        gbd_id=reiid(170),
        distribution=UNKNOWN,
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        affected_causes=(causes.hiv_aids_resulting_in_other_diseases, causes.syphilis, causes.chlamydial_infection, 
                         causes.gonococcal_infection, causes.trichomoniasis, causes.genital_herpes, 
                         causes.other_sexually_transmitted_diseases, causes.cervical_cancer, 
                         causes.drug_susceptible_hiv_aids_tuberculosis, 
                         causes.multidrug_resistant_hiv_aids_tuberculosis_without_extensive_drug_resistance, 
                         causes.extensively_drug_resistant_hiv_aids_tuberculosis, ),
    ),
    intimate_partner_violence_hiv_paf_approach=Risk(
        name='intimate_partner_violence_hiv_paf_approach',
        kind='risk_factor',
        gbd_id=reiid(201),
        distribution=UNKNOWN,
        restrictions=Restrictions(
            male_only=False,
            female_only=True,
            yll_only=False,
            yld_only=False,
        ),
        affected_causes=(causes.hiv_aids_resulting_in_other_diseases, causes.drug_susceptible_hiv_aids_tuberculosis, 
                         causes.multidrug_resistant_hiv_aids_tuberculosis_without_extensive_drug_resistance, 
                         causes.extensively_drug_resistant_hiv_aids_tuberculosis, ),
    ),
    occupational_exposure_to_trichloroethylene=Risk(
        name='occupational_exposure_to_trichloroethylene',
        kind='risk_factor',
        gbd_id=reiid(237),
        distribution='polytomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='high_exposure',
            cat2='low_exposure',
            cat3='unexposed',
        ),
        affected_causes=(causes.kidney_cancer, ),
    ),
    no_access_to_handwashing_facility=Risk(
        name='no_access_to_handwashing_facility',
        kind='risk_factor',
        gbd_id=reiid(238),
        distribution='dichotomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='exposed',
            cat2='unexposed',
        ),
        affected_causes=(causes.diarrheal_diseases, causes.lower_respiratory_infections, ),
    ),
    child_wasting=Risk(
        name='child_wasting',
        kind='risk_factor',
        gbd_id=reiid(240),
        distribution='polytomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='<-3_sd',
            cat2='-3_to_-2_sd',
            cat3='-2_to_-1_sd',
            cat4='unexposed',
        ),
        affected_causes=(causes.diarrheal_diseases, causes.lower_respiratory_infections, causes.measles, 
                         causes.protein_energy_malnutrition, ),
    ),
    child_stunting=Risk(
        name='child_stunting',
        kind='risk_factor',
        gbd_id=reiid(241),
        distribution='polytomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='<-3_sd',
            cat2='-3_to_-2_sd',
            cat3='-2_to_-1_sd',
            cat4='unexposed',
        ),
        affected_causes=(causes.diarrheal_diseases, causes.lower_respiratory_infections, causes.measles, ),
    ),
    lead_exposure_in_blood=Risk(
        name='lead_exposure_in_blood',
        kind='risk_factor',
        gbd_id=reiid(242),
        distribution='unknown_continuous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        tmred=Tmred(
            distribution=UNKNOWN,
            min=UNKNOWN,
            max=UNKNOWN,
            inverted=True,
        ),
        exposure_parameters=ExposureParameters(
            scale=scalar(1.0),
            max_rr=UNKNOWN,
        ),
        affected_causes=(causes.idiopathic_developmental_intellectual_disability, ),
    ),
    lead_exposure_in_bone=Risk(
        name='lead_exposure_in_bone',
        kind='risk_factor',
        gbd_id=reiid(243),
        distribution='ensemble',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        tmred=Tmred(
            distribution='uniform',
            min=scalar(0.0),
            max=scalar(20.0),
            inverted=False,
        ),
        exposure_parameters=ExposureParameters(
            scale=scalar(10.0),
            max_rr=scalar(500.0),
        ),
        affected_causes=(causes.rheumatic_heart_disease, causes.ischemic_heart_disease, causes.ischemic_stroke, 
                         causes.hemorrhagic_stroke, causes.hypertensive_heart_disease, 
                         causes.atrial_fibrillation_and_flutter, causes.aortic_aneurysm, 
                         causes.peripheral_artery_disease, causes.endocarditis, 
                         causes.other_cardiovascular_and_circulatory_diseases, 
                         causes.chronic_kidney_disease_due_to_diabetes_mellitus, 
                         causes.chronic_kidney_disease_due_to_hypertension, 
                         causes.chronic_kidney_disease_due_to_glomerulonephritis, 
                         causes.chronic_kidney_disease_due_to_other_causes, causes.other_cardiomyopathy, ),
    ),
    childhood_sexual_abuse_against_females=Risk(
        name='childhood_sexual_abuse_against_females',
        kind='risk_factor',
        gbd_id=reiid(244),
        distribution='dichotomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='exposed',
            cat2='unexposed',
        ),
        affected_causes=(causes.alcohol_use_disorders, causes.major_depressive_disorder, ),
    ),
    childhood_sexual_abuse_against_males=Risk(
        name='childhood_sexual_abuse_against_males',
        kind='risk_factor',
        gbd_id=reiid(245),
        distribution='dichotomous',
        restrictions=Restrictions(
            male_only=True,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='exposed',
            cat2='unexposed',
        ),
        affected_causes=(causes.alcohol_use_disorders, causes.major_depressive_disorder, ),
    ),
    smokeless_tobacco=Risk(
        name='smokeless_tobacco',
        kind='risk_factor',
        gbd_id=reiid(332),
        distribution='dichotomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='exposed',
            cat2='unexposed',
        ),
        affected_causes=(causes.esophageal_cancer, causes.lip_and_oral_cavity_cancer, ),
    ),
    diet_low_in_legumes=Risk(
        name='diet_low_in_legumes',
        kind='risk_factor',
        gbd_id=reiid(333),
        distribution='ensemble',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        tmred=Tmred(
            distribution='uniform',
            min=scalar(50.0),
            max=scalar(70.0),
            inverted=True,
        ),
        exposure_parameters=ExposureParameters(
            scale=scalar(50.0),
            max_rr=scalar(450.0),
        ),
        affected_causes=(causes.ischemic_heart_disease, ),
    ),
    low_birth_weight_and_short_gestation=Risk(
        name='low_birth_weight_and_short_gestation',
        kind='risk_factor',
        gbd_id=reiid(339),
        distribution='polytomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='[0, 24) wks, [0, 500) g',
            cat2='[24, 26) wks, [0, 500) g',
            cat3='[26, 28) wks, [0, 500) g',
            cat4='[28, 30) wks, [0, 500) g',
            cat5='[0, 24) wks, [500, 1000) g',
            cat6='[24, 26) wks, [500, 1000) g',
            cat7='[26, 28) wks, [500, 1000) g',
            cat8='[32, 34) wks, [500, 1000) g',
            cat9='[0, 24) wks, [1000, 1500) g',
            cat10='[30, 32) wks, [500, 1000) g',
            cat11='[28, 30) wks, [500, 1000) g',
            cat12='[24, 26) wks, [1000, 1500) g',
            cat13='[26, 28) wks, [1000, 1500) g',
            cat14='[26, 28) wks, [1500, 2000) g',
            cat15='[34, 36) wks, [1000, 1500) g',
            cat16='[28, 30) wks, [1500, 2000) g',
            cat17='[28, 30) wks, [1000, 1500) g',
            cat18='[32, 34) wks, [1000, 1500) g',
            cat19='[30, 32) wks, [1000, 1500) g',
            cat20='[37, 38) wks, [1500, 2000) g',
            cat21='[36, 37) wks, [1500, 2000) g',
            cat22='[30, 32) wks, [2000, 2500) g',
            cat23='[30, 32) wks, [1500, 2000) g',
            cat24='[34, 36) wks, [1500, 2000) g',
            cat25='[32, 34) wks, [1500, 2000) g',
            cat26='[32, 34) wks, [2000, 2500) g',
            cat27='[40, 42) wks, [2000, 2500) g',
            cat28='[38, 40) wks, [2000, 2500) g',
            cat29='[32, 34) wks, [2500, 3000) g',
            cat30='[34, 36) wks, [2000, 2500) g',
            cat31='[37, 38) wks, [2000, 2500) g',
            cat32='[36, 37) wks, [2000, 2500) g',
            cat33='[34, 36) wks, [2500, 3000) g',
            cat34='[34, 36) wks, [4000, 4500) g',
            cat35='[34, 36) wks, [3000, 3500) g',
            cat36='[36, 37) wks, [2500, 3000) g',
            cat37='[34, 36) wks, [3500, 4000) g',
            cat38='[37, 38) wks, [2500, 3000) g',
            cat39='[40, 42) wks, [2500, 3000) g',
            cat40='[38, 40) wks, [2500, 3000) g',
            cat41='[36, 37) wks, [3000, 3500) g',
            cat42='[36, 37) wks, [4000, 4500) g',
            cat43='[36, 37) wks, [3500, 4000) g',
            cat44='[37, 38) wks, [3000, 3500) g',
            cat45='[37, 38) wks, [4000, 4500) g',
            cat46='[37, 38) wks, [3500, 4000) g',
            cat47='[40, 42) wks, [3000, 3500) g',
            cat48='[38, 40) wks, [3000, 3500) g',
            cat49='[38, 40) wks, [4000, 4500) g',
            cat50='[38, 40) wks, [3500, 4000) g',
            cat51='[40, 42) wks, [3500, 4000) g',
            cat52='[40, 42) wks, [4000, 4500) g',
            cat53='unexposed',
        ),
        affected_causes=(causes.diarrheal_diseases, causes.lower_respiratory_infections, 
                         causes.upper_respiratory_infections, causes.otitis_media, causes.pneumococcal_meningitis, 
                         causes.h_influenzae_type_b_meningitis, causes.meningococcal_meningitis, 
                         causes.other_meningitis, causes.encephalitis, causes.neonatal_preterm_birth_complications, 
                         causes.neonatal_encephalopathy_due_to_birth_asphyxia_and_trauma, 
                         causes.neonatal_sepsis_and_other_neonatal_infections, 
                         causes.hemolytic_disease_and_other_neonatal_jaundice, causes.other_neonatal_disorders, 
                         causes.sudden_infant_death_syndrome, ),
    ),
    impaired_kidney_function=Risk(
        name='impaired_kidney_function',
        kind='risk_factor',
        gbd_id=reiid(341),
        distribution='polytomous',
        restrictions=Restrictions(
            male_only=False,
            female_only=False,
            yll_only=False,
            yld_only=False,
        ),
        levels=Levels(
            cat1='albuminuria',
            cat2='stage_iii_chronic_kidney_disease',
            cat3='stage_iv_chronic_kidney_disease',
            cat4='stage_v_chronic_kidney_disease',
            cat5='unexposed',
        ),
        affected_causes=(causes.ischemic_heart_disease, causes.ischemic_stroke, causes.hemorrhagic_stroke, 
                         causes.peripheral_artery_disease, causes.chronic_kidney_disease_due_to_diabetes_mellitus, 
                         causes.chronic_kidney_disease_due_to_hypertension, 
                         causes.chronic_kidney_disease_due_to_glomerulonephritis, 
                         causes.chronic_kidney_disease_due_to_other_causes, causes.gout, ),
    ),
)
